# Changelog

## 1.0.1 (2025-10-18)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/brapi-dev/brapi-python/compare/v1.0.0...v1.0.1)

### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([58fd5fc](https://github.com/brapi-dev/brapi-python/commit/58fd5fc95c4b0b4e3f92fc5bca2d6dcea5bbe8c9))

## 1.0.0 (2025-10-12)

Full Changelog: [v0.0.1...v1.0.0](https://github.com/brapi-dev/brapi-python/compare/v0.0.1...v1.0.0)

### Chores

* sync repo ([a54d73b](https://github.com/brapi-dev/brapi-python/commit/a54d73b6e3d9e6f0347ff61d73885cf6cadb4c56))
* update SDK settings ([5313c1b](https://github.com/brapi-dev/brapi-python/commit/5313c1bccd7d4366b768ec14fa6a22cb0ebbefd0))
* update SDK settings ([604a534](https://github.com/brapi-dev/brapi-python/commit/604a534b7fc3daf6e9128a98e74aca9295a02c70))
* update SDK settings ([551afe3](https://github.com/brapi-dev/brapi-python/commit/551afe39d139c11f6e6ace580ed8faa06217a073))
* update SDK settings ([14efeb5](https://github.com/brapi-dev/brapi-python/commit/14efeb558642ad68760ce354f10d6f37a1df7f68))
